@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 sub new {
 	my ($class) = @_;
@@ -390,7 +390,9 @@ sub PT::BoolOperands::X {
 		|| $class->{String}
 		|| $class->{ScalarVariable}
 		|| $class->{ArrayElement}
-		|| $class->{HashElement} )->X($className);
+		|| $class->{HashElement}
+		|| $class->{ClassFunctionReturn}
+		|| $class->{FunctionReturn} )->X($className);
 }
 
 sub PT::ElsIf::X {
@@ -1049,6 +1051,7 @@ my $parser = qr {
     <objrule:  PT::BoolExpression>             <BoolOperands> <BoolOperatorExpression>?
     <objrule:  PT::BoolOperatorExpression>     <BoolOperator> <BoolOperands>
     <objrule:  PT::BoolOperands>               <Number> | <String> | <ScalarVariable> | <ArrayElement> | <HashElement>
+											   | <ClassFunctionReturn> | <FunctionReturn>
     <objrule:  PT::BoolOperator>               <GreaterThan> | <LessThan> | <Equals> | <GreaterThanEquals> | <LessThanEquals>
                                                | <StringEquals> | <StringNotEquals> | <NotEqulas> | <LogicalAnd> | <LogicalOr>
     <objrule:  PT::ElsIf>                      <[ElsIfChain]>+
@@ -1142,8 +1145,8 @@ my $parser = qr {
 
     <objtoken: PT::TokenSTDIN>                 STDIN
 
-    <objtoken: PT::LogicalAnd>		        \&\&
-    <objtoken: PT::LogicalOr>            	\|\|
+    <objtoken: PT::LogicalAnd>                 \&\&
+    <objtoken: PT::LogicalOr>                  \|\|
     <objtoken: PT::NotEqulas>                  \!=
     <objtoken: PT::StringNotEquals>            ne
     <objtoken: PT::StringEquals>               eq
